@@ -1,12 +1,12 @@
-#   @(#)$Id: Informix.pm,v 2010.1 2010/09/01 20:10:57 jleffler Exp $
+#   @(#)$Id: Informix.pm,v 2011.1 2011/09/26 00:48:06 jleffler Exp $
 #
-#   @(#)IBM Informix Database Driver for Perl DBI Version 2011.0612 (2011-06-12)
+#   @(#)IBM Informix Database Driver for Perl DBI Version 2013.0118 (2013-01-18)
 #
 #   Copyright 1994-95 Tim Bunce
 #   Copyright 1996-99 Jonathan Leffler
 #   Copyright 2000    Informix Software Inc
 #   Copyright 2001-03 IBM
-#   Copyright 2004-10 Jonathan Leffler
+#   Copyright 2004-11 Jonathan Leffler
 #
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
@@ -48,10 +48,10 @@
                 ) ] );
     Exporter::export_ok_tags('ix_types');
 
-    $VERSION          = "2011.0612";
+    $VERSION          = "2013.0118";
 
     my $ATTRIBUTION      = 'Jonathan Leffler <jleffler@us.ibm.com>';
-    my $Revision         = '$Id: Informix.pm,v 2010.1 2010/09/01 20:10:57 jleffler Exp $';
+    my $Revision         = '$Id: Informix.pm,v 2011.1 2011/09/26 00:48:06 jleffler Exp $';
 
     # This is for development only - the code must be recompiled each day!
     $VERSION = strftime("%Y.%m%d", localtime time) if ($VERSION =~ m%[:]VERSION[:]%);
@@ -165,6 +165,19 @@
     package DBD::Informix::db; # ====== DATABASE ======
     use strict;
 
+    # Required by DBI and used by Apache::DBI
+    sub ping
+    {
+        my ($dbh) = @_;
+        my $ret = 0;
+        eval {
+            local $SIG{__DIE__}  = sub { return (0); };
+            local $SIG{__WARN__} = sub { return (0); };
+            $ret = $dbh->do('SELECT 1 FROM "informix".systables WHERE TabID = 1');
+        };
+        return ($@) ? 0 : $ret;
+    }
+
     sub get_info
     {
         my ($dbh, $info_type) = @_;
@@ -191,7 +204,6 @@
 
     # This type_info_all function was automatically generated by
     # DBI::DBD::TypeInfo::write_typeinfo v1.00.
-
     sub type_info_all
     {
         my($dbh, $info_type) = @_;
@@ -300,7 +312,7 @@ DBD::Informix - IBM Informix Database Driver for Perl DBI
 
 =head1 DESCRIPTION
 
-This document describes IBM Informix Database Driver for Perl DBI Version 2011.0612 (2011-06-12).
+This document describes IBM Informix Database Driver for Perl DBI Version 2013.0118 (2013-01-18).
 
 You should also read the documentation for DBI C<perldoc DBI> as this
 document qualifies what is stated there.
